.. omniconf documentation master file, created by
   sphinx-quickstart on Fri Sep 16 09:44:32 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to omniconf's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   design
   backends
   types
   examples



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
